--- a/idlefw/plugins/sapidataplugin/inc/sapidata.h Fri Mar 12 15:43:54 2010 +0200
+++ b/idlefw/plugins/sapidataplugin/inc/sapidata.h Mon Mar 15 12:41:53 2010 +0200
@@ -270,14 +270,20 @@
/**
* Called by the observer to refresh the changed content
*
* @param aPublisher publisher.
* @param aContentType content type.
* @param aContentId content Id.
* @param aOperation operation (add/delete/update/execute).
* @return void
*/
- void RefreshL( TDesC& aPublisher, TDesC& aContentType,
- TDesC& aContentId, TDesC& aOperation );
+ void RefreshL( TDesC& aPublisher,
+ TDesC& aContentType,
+ TDesC& aContentId,
+ TDesC& aOperation,
+ CLiwDefaultMap* aDataMap );
/**
* Createts the filter map and push it in the stack
@@ -270,14 +270,20 @@
* Called by the observer to refresh the changed content
*
- * @param aPublisher publisher.
- * @param aContentType content type.
- * @param aContentId content Id.
- * @param aOperation operation (add/delete/update/execute).
+ * @param aPublisher publisher.
+ * @param aContentType content type.
+ * @param aContentId content Id.
+ * @param aOperation operation (add/delete/update/execute).
+ * @param aDataMap data map if available. Can be NULL.
+ * Ownership NOT transferred.
+ *
* @return void
*/